@@ -1,4 +1,4 @@
-from . import handlers as on
+from . import events
 from . import objects as objects
 from . import requests as bot
 from .base import UserProxyModel, Constants, exceptions as exc, UserModel
