@@ -8,7 +8,7 @@ from ..base.exceptions import StopProcessing, ExitHandler
 from ..base.user_model import UserModel
 from ..base.user_proxy_model import UserProxyModel
 from ..context import ctx
-from ..handlers.base import Handler
+from ..events.base import Handler
 from ..objects.tg_objects import Update
 from ..requests.get_updates import get_updates
 from ..utils import cast
