@@ -4,9 +4,6 @@ import mongoengine
 import requests
 from envparse import env
 
-from .dispatcher import Dispatcher
-from .handlers.base import Handler
-
 BOT_TOKEN = env('BOT_TOKEN')
 MONGO_DB = env('MONGO_DB')
 MONGO_HOST = env('MONGO_HOST', 'localhost')
@@ -14,7 +11,3 @@ MONGO_HOST = env('MONGO_HOST', 'localhost')
 logger = logging.getLogger('bot')
 mongoengine.connect(MONGO_DB, host=MONGO_HOST)
 session = requests.Session()
-
-dp = Dispatcher()
-
-HANDLERS: list[Handler] = []
